@@ -1,11 +1,12 @@
 import sys
 import typer
 
+from typing import Tuple
 from chris.cube.pipeline import Pipeline
 from chris.cube.plugin_instance import PluginInstance
 
 
-def run_pipeline_with_progress(chris_pipeline: Pipeline, plugin_instance: PluginInstance):
+def run_pipeline_with_progress(chris_pipeline: Pipeline, plugin_instance: PluginInstance) -> Tuple[PluginInstance, ...]:
     """
     Helper to execute a pipeline with a progress bar.
     """
@@ -13,5 +14,4 @@ def run_pipeline_with_progress(chris_pipeline: Pipeline, plugin_instance: Plugin
     with typer.progressbar(plugin_root.run(plugin_instance.id),
                            length=len(plugin_root), label='Scheduling pipeline',
                            file=sys.stderr) as proto_pipeline:
-        for _ in proto_pipeline:
-            pass
+        return tuple(plugin_instance for plugin_instance in proto_pipeline)
